// ==============================================================================
// 												
// Author:		if this code doesn't work, it was written by Alan Smithee
//
// Copyright:	Plan Software GmbH, Saarbrcken
//  
// ==============================================================================

// associative array from mechanics id to all motion profiles that are possible in
// combination with that mechanic
var mp_array=new Array();
mp_array['CRotatingSpindleController'] = 'CStandardLinearController,CRelativePowerOnTimeController,CFlyingCutOffController,CPressFeederController';
mp_array['CRotatingNutController'] = 'CStandardLinearController,CRelativePowerOnTimeController,CFlyingCutOffController,CPressFeederController';
mp_array['CRackAndPinionController'] = 'CStandardLinearController,CRelativePowerOnTimeController,CFlyingCutOffController,CPressFeederController';
mp_array['CBeltAndPulleyController'] = 'CStandardLinearController,CRelativePowerOnTimeController,CFlyingCutOffController,CPressFeederController';
mp_array['CLinearDriveController'] = 'CStandardLinearController,CRelativePowerOnTimeController,CFlyingCutOffController,CPressFeederController';
mp_array['CRotaryDriveController'] = 'CStandardRotativeController,CRelativePowerOnTimeController';
mp_array['CRollFeedController'] = 'CStandardLinearController,CRelativePowerOnTimeController,CFlyingCutOffController,CPrintEmbossController';
mp_array['CRotaryKnifeController'] = 'CMPRotaryKnifeController';
mp_array['CWinderMechanicsController'] = 'CWinderController';
mp_array['CRollerFeedController'] = 'CRollFeedIntermittedController';


// associative array from motion profile id to all mechanicss that are possible in
// combination with that motion profile
var mech_array=new Array();
mech_array['CStandardLinearController'] = 'CRotatingSpindleController,CRotatingNutController,CBeltAndPulleyController,CRackAndPinionController,CLinearDriveController,CRollFeedController';
mech_array['CStandardRotativeController'] = 'CRotaryDriveController';
mech_array['CRollFeedIntermittedController'] = 'CRollerFeedController';
mech_array['CPressFeederController'] = 'CRotatingSpindleController,CRotatingNutController,CBeltAndPulleyController,CRackAndPinionController,CLinearDriveController';
mech_array['CFlyingCutOffController'] = 'CRotatingSpindleController,CRotatingNutController,CBeltAndPulleyController,CRackAndPinionController,CLinearDriveController,CRollFeedController';
mech_array['CPrintEmbossController'] = 'CRollFeedController';
mech_array['CMPRotaryKnifeController'] = 'CRotaryKnifeController';
mech_array['CWinderController'] = 'CWinderMechanicsController';
mech_array['CRelativePowerOnTimeController'] = 'CRotatingSpindleController,CRotatingNutController,CBeltAndPulleyController,CRackAndPinionController,CRotaryDriveController,CLinearDriveController,CRollFeedController';


// ==============================================================================
//
// Function  : InitTables
//
// Purpose   : inits the mechanics and motion profile tables with entry values
//
// Parameter : none
//
// Returns   : nothing
//
// ==============================================================================

function InitTables()
{
	// get entry values
	var strCurrentMechanics = document.getElementById( 'IDC_MECH_TAB_SELECTED' ).value;
	var strCurrentMotionProfile = document.getElementById( 'IDC_MOVE_TAB_SELECTED' ).value;
	
	// get cells for values
	var elMech = GetCellWithValue( 'IDC_MECHANIK_TAB_TABLE', strCurrentMechanics );
	var elMP = GetCellWithValue( 'IDC_BEWEGUNG_TAB_TABLE', strCurrentMotionProfile );

	// simulate click events for mechanics and motion profiles
	if ( elMP != null )
	{
		// we must mark the current motion profile before we can select the mechanics
		// get selected motion profile object
		var el = document.getElementById( elMP );
		
		//if ( el.nodeName != 'TD' ) 
		//	el = getElementFromElementByTagName( el, 'TD' );

		// mark current motion profile
		var cn = el.parentNode.childNodes;
		for ( var i = 0; i < cn.length; i++ ) 
		{
			if ( ( cn[i].nodeName == 'TD' ) && ( cn[i].id == strCurrentMotionProfile ) )
				cn[i].style.backgroundColor = 'yellow';
		}	
		// select the current mechanics
		if ( elMech != null )
			SelectMechanic( elMech, 'false' );

		// now we can select the motion profile as usual
		SelectMotionProfile( elMP, 'false' );
	}

}


// ==============================================================================
//
// Function  : GetCellWithValue
//
// Purpose   : retrieves the cell object from a table that has a given value
//
// Parameter : - strTableID: Type string
//				 name of the table
//             - strValue: Type string
//				 value of cell whose handle is searched
//
// Returns   : element : Type Object
//             handle of cell
//             (null if none exists or on errors)
//
// ==============================================================================

function GetCellWithValue( strTableID, strValue )
{
	var element = null;
	var table = document.getElementById(strTableID);//getElement( strTableID );

	if ( table != null )
	{
		for ( var i = 0; i < table.rows.length; i++ ) 
		{
			for ( var j = 0; j < table.rows[i].cells.length; j++ ) 
			{
				if ( table.rows[i].cells[j].id == strValue )
				{
					element = table.rows[i].cells[j].id;
					break;
				}
			}
		}
	}

	return( element );
}


// ==============================================================================
//
// Function  : SelectMechanic
//
// Purpose   : selects a mechanics, disables or enables its corresponding motion 
//             profiles and sets a default motion profile, if none is selected or
//             the current selected one is not possible anymore
//
// Parameter : evt - Type String
//             cell id of mechanics table cell that has been clicked
//             strResetFields - Type String
//             false : don't reset all fields to white before selecting (use it only to 
//                     initialise the table)
//             else : reset all fields to white before selecting
//
// Returns   : nothing
//
// ==============================================================================

function SelectMechanic( strElId, strElName,strResetFields ) 
{
	var el = document.getElementById(strElId);
	var idx = strElId;                                    
	document.getElementById('IDC_MECH_TAB_SELECTED').value = idx;

	// alert(mp_array[idx]);
	var mp_keys = mp_array[idx].split(',');
	var is_ok;
	
	var mp_table = document.getElementById('IDC_MECHANIK_TAB_TABLE');
	if ( strResetFields != 'false' )
	{
		// Alle Felder der Tabelle grau machen:
		for (var j=0; j < mp_table.rows.length; j++) 
		{
			for (var k=0; k < mp_table.rows[j].cells.length; k++) 
			{
				mp_table.rows[j].cells[k].style.backgroundColor = 'lightgrey';
			}
		}
	}
	
	mp_table 	= document.getElementById('IDC_BEWEGUNG_TAB_TABLE');
	// Alle Felder der Tabelle grau machen:
	for (var j=0; j < mp_table.rows.length; j++) 
	{
		for (var k=0; k < mp_table.rows[j].cells.length; k++) 
		{
			if (mp_table.rows[j].cells[k].style.backgroundColor != 'yellow')
				mp_table.rows[j].cells[k].style.backgroundColor = 'lightgrey';
		}
	}
	
	
	// Felder je nach Auswahl verstecken:	
	IndexOfYellowElement = -1;	
	for (var j=0; j < mp_table.rows.length; j++) 
	{
		for (var k=0; k < mp_table.rows[j].cells.length; k++) 
		{
			is_ok = false;
							
			for (var i=0; i < mp_keys.length; i++) 
			{	
				if ( mp_table.rows[j].cells[k].id == mp_keys[i]) 
				{
					is_ok = true;
					if (mp_table.rows[j].cells[k].style.backgroundColor == 'yellow')
					{
						IndexOfYellowElement = i;
					}
				}
			}
			
			if (is_ok == false)
			{
				mp_table.rows[j].cells[k].style.visibility = 'hidden';
				mp_table.rows[j].cells[k].style.backgroundColor = 'lightgrey';
		    }
			else mp_table.rows[j].cells[k].style.visibility = 'visible';
			//	mp_table.rows[j].cells[k].style.backgroundColor = 'lightgrey';
			//else mp_table.rows[j].cells[k].style.backgroundColor = 'white';
		}
	}
	//alert("IndexOfYellowElement: " + IndexOfYellowElement);
	if (IndexOfYellowElement < 0)
		IndexOfYellowElement = 0;
	for (var j=0; j < mp_table.rows.length; j++) 
	{
		for (var k=0; k < mp_table.rows[j].cells.length; k++) 
		{
			if ( mp_table.rows[j].cells[k].id == mp_keys[IndexOfYellowElement]) 
			{
				mp_table.rows[j].cells[k].style.backgroundColor = 'yellow';
				document.getElementById('IDC_MOVE_TAB_SELECTED').value = mp_keys[IndexOfYellowElement];
			}
		}
	}
	
	cn = el.parentNode.childNodes;
	for (var i=0; i < cn.length; i++) 
	{
		if (cn[i].nodeName == 'TD' && cn[i].id == idx) 
		{
			if(i==2){
				try{
					cn[(i-1)].style.backgroundColor = 'yellow';
				}
				catch(err){}
			}
			else
				try{
					cn[(i+1)].style.backgroundColor = 'yellow';
				}
				catch(err){}	
				
			cn[i].style.backgroundColor = 'yellow';
		}
	}
}


// ======================================================================================
//
// Function  : SelectMotionProfile
//
// Purpose   : selects a motion profile, disables or enables its corresponding mechanics
//             and sets a default mechanic, if none is selected or the current selected 
//             one is not possible anymore
//
// Parameter : evt - Type String
//             cell id of motion profile table cell that has been clicked
//             strResetFields - Type String
//             false : don't reset all fields to white before selecting (use it only to 
//                     initialise the table)
//             else : reset all fields to white before selecting
//
// Returns   : nothing
//
// ======================================================================================

function SelectMotionProfile( strElId, strElName,strResetFields )
{
	var el = document.getElementById(strElId);
	var idx = strElId; 
	document.getElementById("IDC_MOVE_TAB_SELECTED").value = idx;
	
	//alert(mech_array[idx]);
	
	var mech_keys 	= mech_array[idx].split(',');
	var is_ok;

	var mech_table 	= document.getElementById('IDC_BEWEGUNG_TAB_TABLE');
	if ( strResetFields != 'false' )
	{
		// Alle Felder der Tabelle grau machen:
		for (var j=0; j < mech_table.rows.length; j++) 
		{
			for (var k=0; k < mech_table.rows[j].cells.length; k++) 
			{
				mech_table.rows[j].cells[k].style.backgroundColor = 'lightgrey';
			}
		}
	}

	mech_table 	= document.getElementById('IDC_MECHANIK_TAB_TABLE');
	
	// Alle Felder der Tabelle wei machen:
	for (var j=0; j < mech_table.rows.length; j++) 
	{
		for (var k=0; k < mech_table.rows[j].cells.length; k++) 
		{
			if (mech_table.rows[j].cells[k].style.backgroundColor != 'yellow')
				mech_table.rows[j].cells[k].style.backgroundColor = 'lightgrey';
		}
	}
			
	// Felder je nach Auswahl verstecken:

	IndexOfYellowElement = -1;
	
	for (var j=0; j < mech_table.rows.length; j++) 
	{
		for (var k=0; k < mech_table.rows[j].cells.length; k++) 
		{
			is_ok = false;
			
			for (var i=0; i < mech_keys.length; i++) 
			{
				if ( mech_table.rows[j].cells[k].id == mech_keys[i]) 
				{
					is_ok = true;
					if (mech_table.rows[j].cells[k].style.backgroundColor == 'yellow')
						IndexOfYellowElement = i;
				}		
			}
			if (is_ok == false)
			{
				mech_table.rows[j].cells[k].style.visibility = 'hidden';
				mech_table.rows[j].cells[k].style.backgroundColor = 'lightgrey';
			}
			else mech_table.rows[j].cells[k].style.visibility = 'visible';
				//mech_table.rows[j].cells[k].style.backgroundColor = 'lightgrey';
			//else mech_table.rows[j].cells[k].style.backgroundColor = 'white';
		}	
	}
	if (IndexOfYellowElement < 0)
		IndexOfYellowElement = 0;
	for (var j=0; j < mech_table.rows.length; j++) 
	{
		for (var k=0; k < mech_table.rows[j].cells.length; k++) 
		{
			if ( mech_table.rows[j].cells[k].id == mech_keys[IndexOfYellowElement]) 
			{
				mech_table.rows[j].cells[k].style.backgroundColor = 'yellow';
				document.getElementById('IDC_MECH_TAB_SELECTED').value = mech_keys[IndexOfYellowElement];
			}
		}
	}

	cn = el.parentNode.childNodes;
	for (var l=0; l < cn.length; l++) 
	{
		if (cn[l].nodeName == 'TD' && cn[l].id == idx) 
		{
			cn[l].style.backgroundColor = 'yellow';
		}
	}	
}			


// ==============================================================================
//
// Function  : CheckContinueEvent
//
// Purpose   : asks wether the user wants to proceed with the continue event,
//             if he has modified his previous selection of motion profile or
//             mechanics
//
// Parameter : event: type string
//				   id of button that evokes this function
//
// Returns   : nothing
//
// ==============================================================================

function CheckContinueEvent( event )
{
	// get entry values
	var strOldMechanics = document.getElementById( 'MECHANICS_SELECTED' ).value;
	var strOldMotionProfile = document.getElementById( 'MP_SELECTED' ).value;

	//alert( 'Old Mechanics: ' + strOldMechanics + ', Old Motion Profile: ' + strOldMotionProfile );

	var bSubmit = false;
	if ( ( strOldMechanics == null ) || ( strOldMechanics == '' ) ||
		 ( strOldMotionProfile == null ) || ( strOldMotionProfile == '' ) )
	{
		// that means we have just started a new selection and don't have to check for 
		// selection changings
		bSubmit = true;
	}
	else
	{
		// get current selections
		var strCurrentMechanics = document.getElementById( 'IDC_MECH_TAB_SELECTED' ).value;
		var strCurrentMotionProfile = document.getElementById( 'IDC_MOVE_TAB_SELECTED' ).value;

		//alert( 'Current Mechanics: ' + strCurrentMechanics + ', Current Motion Profile: ' + strCurrentMotionProfile );
		var strDisplayMessage = '';
		
		// compare current selections to old selctions
		if ( strCurrentMechanics != strOldMechanics )
		{
			if ( strCurrentMotionProfile != strOldMotionProfile )
				strDisplayMessage = GetMessage( 'MESSAGE_BOTH_CHANGED' );
			else strDisplayMessage = GetMessage( 'MESSAGE_MECHANICS_CHANGED' );
		}
		else if ( strCurrentMotionProfile != strOldMotionProfile )
				strDisplayMessage = GetMessage( 'MESSAGE_MP_CHANGED' );
		else bSubmit = true;

		if ( strDisplayMessage != '' )
		{
			// display message
			var ret = window.confirm( strDisplayMessage );

			if ( ret )
				bSubmit = true;
			else
			{
				// reset UI to previous selection
				document.getElementById( 'IDC_MECH_TAB_SELECTED' ).value = strOldMechanics;
				document.getElementById( 'IDC_MOVE_TAB_SELECTED' ).value = strOldMotionProfile;
				InitTables();
			}
		}
	}

	// sometimes a script has to do what a script has to do
	if ( bSubmit )
		ekSubmit( event );
}


// ==============================================================================
//
// Function  : GetMessage
//
// Purpose   : gets a message text for an element id
//
// Parameter : id: type string
//				   id of element that contains the message text
//
// Returns   : the message text or an empty string, if no element with this id 
//             exists
//
// ==============================================================================

function GetMessage( id )
{
	var elMsg = document.getElementById( id );
	if ( elMsg == null )
		elMsg = parent.document.getElementById( id );

	if ( elMsg == null )
		return( '' );

	return( elMsg.value );
}


// ==============================================================================
//
// Function  : CheckReset
//
// Purpose   : asks wether the user wants to proceed with resetting the current dlg
//
// Parameter : event: type string
//				id of button that evokes this function
//
// Returns   : nothing
//
// ==============================================================================

function CheckReset( event )
{
	var element = document.getElementById( 'RESET_MESSAGE' );
	if ( element )
	{
		var ret = null;
		var strMessage = element.value;
		if ( strMessage != '' )
			ret = window.confirm( strMessage );
		if ( ret )
			Reset( event );
	}
	else Reset( event );
}


// ==============================================================================
//
// Function  : Reset
//
// Purpose   : resets the current selection to none
//
// Parameter : none
//
// Returns   : nothing
//
// ==============================================================================

function Reset()
{
	document.getElementById( 'IDC_MECH_TAB_SELECTED' ).value = "";
	document.getElementById( 'IDC_MOVE_TAB_SELECTED' ).value = "";
	document.getElementById( 'IDC_RESET_BUTTON' ).onclicked = "Reset();";
	document.getElementById( 'IDC_SAVE_UNFINISHED_BUTTON' ).disabled = "false";
	// alle Felder der Tabelle fr Bewegungsprofile grau machen:
	var mp_table = document.getElementById('IDC_BEWEGUNG_TAB_TABLE');

	for (var j=0; j < mp_table.rows.length; j++) 
	{
		for (var k=0; k < mp_table.rows[j].cells.length; k++) 
		{
			mp_table.rows[j].cells[k].style.backgroundColor = 'lightgrey';
			mp_table.rows[j].cells[k].style.visibility = 'visible';
		}
	}

	// alle Felder der Tabelle fr Mechaniken grau machen:
	var mech_table 	= document.getElementById('IDC_MECHANIK_TAB_TABLE');
	for (var j=0; j < mech_table.rows.length; j++) 
	{
		for (var k=0; k < mech_table.rows[j].cells.length; k++) 
		{
			mech_table.rows[j].cells[k].style.backgroundColor = 'lightgrey';
			mech_table.rows[j].cells[k].style.visibility = 'visible';
		}
	}
}

