// ==============================================================================
// 												
// Author:		if this code doesn't work, it was written by Alan Smithee
//
// Copyright:	Plan Software GmbH, Saarbrcken
//  
// ==============================================================================


// ==============================================================================
//
// Function  : CheckDeleteCAMEvent
//
// Purpose   : asks wether the user wants to proceed with deleting the input from
//             a CAM file
//
// Parameter : event: type string
//				id of button that evokes this function
//             format: type string
//              delete min. (MIN) or max. (MAX) format length
//             update: type string
//              use update (1) or delete message (0)
//
// Returns   : nothing
//
// ==============================================================================

function CheckDeleteCAMEvent( event, format, update )
{
    var cam_disabled = document.getElementById( 'CAM_DISABLED' );
    if ( cam_disabled )
    {
        // if we have multiple number of knifes in the mechanics, the CAM tab is fully disabled, so we must suppress 
        // every action
        if ( cam_disabled.value != 'false' )
            return;
    }
        
	var element = null;	
	if ( ( format == 'MAX' ) && ( update == '0' ) )
	    element = document.getElementById( 'DELETE_MAX_FORMATLENGTH_MESSAGE' );
	else if ( ( format == 'MIN' ) && ( update == '0' ) )
	    element = document.getElementById( 'DELETE_MIN_FORMATLENGTH_MESSAGE' );
	else if ( ( format == 'MAX' ) && ( update == '1' ) )
	    element = document.getElementById( 'UPDATE_MAX_FORMATLENGTH_MESSAGE' );
	else if ( ( format == 'MIN' ) && ( update == '1' ) )
	    element = document.getElementById( 'UPDATE_MIN_FORMATLENGTH_MESSAGE' );
	if ( element )
	{
		var ret = null;
		var strMessage = element.value;
		if ( strMessage != '' )
			ret = window.confirm( strMessage );
		else ret = 'true';
		if ( ret )
			ekSubmit( event );
	}
	else ekSubmit( event );
}



// ==============================================================================
//
// Function  : SetVelocitiesEqual
//
// Purpose   : sets the velocities for minimal and maximal formatlength equal, 
//             when the user leaves either one input field
//
// Parameter : strMinMax: type string
//              user leaves velocity field for min. (MIN) or max. (MAX) format length
//
// Returns   : nothing
//
// ==============================================================================

function SetVelocitiesEqual( strMinMax )
{
    var cam_disabled = document.getElementById( 'CAM_DISABLED' );
    if ( cam_disabled )
    {
        // if we have multiple number of knifes in the mechanics, the CAM tab is fully disabled, so we must suppress 
        // every action
        if ( cam_disabled.value != 'false' )
            return;
    }
        
    if ( strMinMax == 'MIN' )
    {
        // get velocity for min. formatlength
    	strZahl = document.getElementById( 'IDC_CAM_MIN_MAX_MATERIALGESCHWINDIGKEIT_EDIT' ).value;
    	
        // set velocity for max. formatlength
    	document.getElementById( 'IDC_CAM_MAX_MAX_MATERIALGESCHWINDIGKEIT_EDIT' ).value = strZahl;
    }
    else
    {
        // get velocity for max. formatlength
    	strZahl = document.getElementById( 'IDC_CAM_MAX_MAX_MATERIALGESCHWINDIGKEIT_EDIT' ).value;

        // set velocity for min. formatlength
    	document.getElementById( 'IDC_CAM_MIN_MAX_MATERIALGESCHWINDIGKEIT_EDIT' ).value = strZahl;
    }
}


// ==============================================================================
//
// Function  : CheckSelectedTab
//
// Purpose   : asks wether the user wants to proceed with to the motorsearch dialog
//
// Parameter : event: type string
//				id of button that evokes this function
//
// Returns   : nothing
//
// ==============================================================================

function CheckSelectedTab( event )
{
    // get current selected tab
    var tabCtrl = document.getElementById( 'IDC_MOTION_PROFILE_TAB' );
    var strTab = dialog['IDC_MOTION_PROFILE_TAB'].selected;
    
    var cam_disabled = document.getElementById( 'CAM_DISABLED' );
    if ( cam_disabled )
    {
        // if we have multiple number of knifes in the mechanics, the CAM tab is fully disabled, so we can't proceed
        // on 'next' button event, if the CAM table is selected
        if ( ( cam_disabled.value != 'false' ) && ( strTab == 'CAMBUILDER' ) )
            return;
    }
        
    var hide_cam = document.getElementById( 'HIDE_CAM_IMPORT' );
    if ( hide_cam )
    {
        // if the CAM-import tab is not shown, we need no confirming message but can proceed directly
        if ( hide_cam.value == 'true' )
        {
            ekSubmit( event );
            return;
        }
    }

    // 'ask text' is eliminated by request of ID #7782
    ekSubmit( event );
}
