/**
 * motion profile related scripts
 *
 * @category   motion profile
 * @package    IndraSize
 * @copyright  Copyright (c) 2006-2010 Plan Software GmbH (http://www.plansoft.de)
 */

// -------------------------------------------------------------------------------------------------------------------------------------------------
// global data structures
// -------------------------------------------------------------------------------------------------------------------------------------------------

// structures for linear motion profile
// associative array from checkbox id to id's of associated edit field and combobox
var g_aIDArrayLinear = {};

g_aIDArrayLinear['IDC_TAB_WEG_CHECKBOX'] = 'IDC_WEG_EDIT,IDC_WEG_COMBO';
g_aIDArrayLinear['IDC_TAB_ZEIT_CHECKBOX'] = 'IDC_ZEIT_EDIT,IDC_ZEIT_COMBO';
g_aIDArrayLinear['IDC_TAB_BESCHLEUNIGUNG_CHECKBOX'] = 'IDC_BESCHLEUNIGUNG_EDIT,IDC_BESCHLEUNIGUNG_COMBO';
g_aIDArrayLinear['IDC_TAB_GESCHWINDIGKEIT_CHECKBOX'] = 'IDC_GESCHWINDIGKEIT_EDIT,IDC_GESCHWINDIGKEIT_COMBO';

g_aIDArrayLinear['IDC_TAB_DREIECK_WEG_CHECKBOX'] = 'IDC_WEG_DREIECK_EDIT,IDC_WEG_DREIECK_COMBO';
g_aIDArrayLinear['IDC_TAB_DREIECK_ZEIT_CHECKBOX'] = 'IDC_ZEIT_DREIECK_EDIT,IDC_ZEIT_DREIECK_COMBO';
g_aIDArrayLinear['IDC_TAB_DREIECK_BESCHLEUNIGUNG_CHECKBOX'] = 'IDC_BESCHLEUNIGUNG_DREIECK_EDIT,IDC_BESCHLEUNIGUNG_DREIECK_COMBO';
g_aIDArrayLinear['IDC_TAB_DREIECK_GESCHWINDIGKEIT_CHECKBOX'] = 'IDC_GESCHWINDIGKEIT_DREIECK_EDIT,IDC_GESCHWINDIGKEIT_DREIECK_COMBO';

g_aIDArrayLinear['IDC_TRAPEZ_TAB_WEG_CHECKBOX'] = 'IDC_WEG_TRAPEZ_EDIT,IDC_WEG_TRAPEZ_COMBO';
g_aIDArrayLinear['IDC_TRAPEZ_TAB_ZEIT_CHECKBOX'] = 'IDC_ZEIT_TRAPEZ_EDIT,IDC_ZEIT_TRAPEZ_COMBO';
g_aIDArrayLinear['IDC_TRAPEZ_TAB_BESCHLEUNIGUNG_CHECKBOX'] = 'IDC_BESCHLEUNIGUNG_TRAPEZ_EDIT,IDC_BESCHLEUNIGUNG_TRAPEZ_COMBO';
g_aIDArrayLinear['IDC_TRAPEZ_TAB_GESCHWINDIGKEIT_CHECKBOX'] = 'IDC_GESCHWINDIGKEIT_TRAPEZ_EDIT,IDC_GESCHWINDIGKEIT_TRAPEZ_COMBO';

// associative array from phase type to id's of associated check boxes that must
// be disabled in this phase
var g_aPhaseBoxesLinear = {};
g_aPhaseBoxesLinear['ACCELERATE'] = '';
g_aPhaseBoxesLinear['STARTER'] = 'IDC_TAB_BESCHLEUNIGUNG_CHECKBOX';
g_aPhaseBoxesLinear['BRAKE'] = '';
g_aPhaseBoxesLinear['CONSTANT'] = 'IDC_TAB_BESCHLEUNIGUNG_CHECKBOX,IDC_TAB_GESCHWINDIGKEIT_CHECKBOX';
g_aPhaseBoxesLinear['WAIT'] = 'IDC_TAB_WEG_CHECKBOX,IDC_TAB_BESCHLEUNIGUNG_CHECKBOX,IDC_TAB_GESCHWINDIGKEIT_CHECKBOX';
g_aPhaseBoxesLinear['OTHER_MOTION'] = 'IDC_TAB_WEG_CHECKBOX,IDC_TAB_BESCHLEUNIGUNG_CHECKBOX,IDC_TAB_GESCHWINDIGKEIT_CHECKBOX';

// associative array from tabulator type to available checkboxes
var g_aAvailableBoxesLinear = {};
g_aAvailableBoxesLinear['SINGLE'] = 'IDC_TAB_WEG_CHECKBOX,IDC_TAB_ZEIT_CHECKBOX,IDC_TAB_BESCHLEUNIGUNG_CHECKBOX,IDC_TAB_GESCHWINDIGKEIT_CHECKBOX';
g_aAvailableBoxesLinear['TRIANGLE'] = 'IDC_TAB_DREIECK_WEG_CHECKBOX,IDC_TAB_DREIECK_ZEIT_CHECKBOX,IDC_TAB_DREIECK_BESCHLEUNIGUNG_CHECKBOX,IDC_TAB_DREIECK_GESCHWINDIGKEIT_CHECKBOX';
g_aAvailableBoxesLinear['TRAPEZE'] = 'IDC_TRAPEZ_TAB_WEG_CHECKBOX,IDC_TRAPEZ_TAB_ZEIT_CHECKBOX,IDC_TRAPEZ_TAB_BESCHLEUNIGUNG_CHECKBOX,IDC_TRAPEZ_TAB_GESCHWINDIGKEIT_CHECKBOX';

// associative array from tabulator type to maximum number of possible checkboxes
var g_aMaxNumberLinear = {};
g_aMaxNumberLinear['SINGLE'] = '2';
g_aMaxNumberLinear['TRIANGLE'] = '2';
g_aMaxNumberLinear['TRAPEZE'] = '3';

// associative array from tabulator type to checkboxes that must be always set
var g_aCheckAlwaysLinear = {};
g_aCheckAlwaysLinear['WAIT'] = 'IDC_TAB_ZEIT_CHECKBOX';
g_aCheckAlwaysLinear['OTHER_MOTION'] = 'IDC_TAB_ZEIT_CHECKBOX';


// structures for rotative motion profile
// associative array from checkbox id to id's of associated edit field and combobox
var g_aIDArrayRotative = {};

g_aIDArrayRotative['IDC_TAB_BEWEGUNG_WINKEL_CHECKBOX'] = 'IDC_WINKEL_EDIT,IDC_WINKEL_COMBO';
g_aIDArrayRotative['IDC_TAB_BEWEGUNG_ZEIT_CHECKBOX'] = 'IDC_ZEIT_EDIT,IDC_ZEIT_COMBO';
g_aIDArrayRotative['IDC_TAB_BEWEGUNG_BESCHLEUNIGUNG_CHECKBOX'] = 'IDC_DREHBESCHLEUNIGUNG_EDIT,IDC_DREHBESCHLEUNIGUNG_COMBO';
g_aIDArrayRotative['IDC_TAB_BEWEGUNG_DREHZAHL_CHECKBOX'] = 'IDC_DREHZAHL_EDIT,IDC_DREHZAHL_COMBO';

g_aIDArrayRotative['IDC_TAB_DREIECK_WINKEL_CHECKBOX'] = 'IDC_WINKEL_DREIECK_EDIT,IDC_WINKEL_DREIECK_COMBO';
g_aIDArrayRotative['IDC_TAB_DREIECK_ZEIT_CHECKBOX'] = 'IDC_ZEIT_DREIECK_EDIT,IDC_ZEIT_DREIECK_COMBO';
g_aIDArrayRotative['IDC_TAB_DREIECK_BESCHLEUNIGUNG_CHECKBOX'] = 'IDC_DREHBESCHLEUNIGUNG_DREIECK_EDIT,IDC_DREHBESCHLEUNIGUNG_DREIECK_COMBO';
g_aIDArrayRotative['IDC_TAB_DREIECK_DREHZAHL_CHECKBOX'] = 'IDC_DREHZAHL_DREIECK_EDIT,IDC_DREHZAHL_DREIECK_COMBO';

g_aIDArrayRotative['IDC_TAB_TRAPEZ_WINKEL_CHECKBOX'] = 'IDC_WINKEL_TRAPEZ_EDIT,IDC_WINKEL_TRAPEZ_COMBO';
g_aIDArrayRotative['IDC_TAB_TRAPEZ_ZEIT_CHECKBOX'] = 'IDC_ZEIT_TRAPEZ_EDIT,IDC_ZEIT_TRAPEZ_COMBO';
g_aIDArrayRotative['IDC_TAB_TRAPEZ_BESCHLEUNIGUNG_CHECKBOX'] = 'IDC_DREHBESCHLEUNIGUNG_TRAPEZ_EDIT,IDC_DREHBESCHLEUNIGUNG_TRAPEZ_COMBO';
g_aIDArrayRotative['IDC_TAB_TRAPEZ_DREHZAHL_CHECKBOX'] = 'IDC_DREHZAHL_TRAPEZ_EDIT,IDC_DREHZAHL_TRAPEZ_COMBO';

// associative array from phase type to id's of associated check boxes that must
// be disabled in this phase
var g_aPhaseBoxesRotative = {};
g_aPhaseBoxesRotative['ACCELERATE'] = '';
g_aPhaseBoxesRotative['STARTER'] = 'IDC_TAB_BEWEGUNG_BESCHLEUNIGUNG_CHECKBOX';
g_aPhaseBoxesRotative['BRAKE'] = '';
g_aPhaseBoxesRotative['CONSTANT'] = 'IDC_TAB_BEWEGUNG_BESCHLEUNIGUNG_CHECKBOX,IDC_TAB_BEWEGUNG_DREHZAHL_CHECKBOX';
g_aPhaseBoxesRotative['WAIT'] = 'IDC_TAB_BEWEGUNG_WINKEL_CHECKBOX,IDC_TAB_BEWEGUNG_BESCHLEUNIGUNG_CHECKBOX,IDC_TAB_BEWEGUNG_DREHZAHL_CHECKBOX';
g_aPhaseBoxesRotative['OTHER_MOTION'] = 'IDC_TAB_BEWEGUNG_WINKEL_CHECKBOX,IDC_TAB_BEWEGUNG_BESCHLEUNIGUNG_CHECKBOX,IDC_TAB_BEWEGUNG_DREHZAHL_CHECKBOX';

// associative array from tabulator type to available checkboxes
var g_aAvailableBoxesRotative = {};
g_aAvailableBoxesRotative['SINGLE'] = 'IDC_TAB_BEWEGUNG_WINKEL_CHECKBOX,IDC_TAB_BEWEGUNG_ZEIT_CHECKBOX,IDC_TAB_BEWEGUNG_BESCHLEUNIGUNG_CHECKBOX,IDC_TAB_BEWEGUNG_DREHZAHL_CHECKBOX';
g_aAvailableBoxesRotative['TRIANGLE'] = 'IDC_TAB_DREIECK_WINKEL_CHECKBOX,IDC_TAB_DREIECK_ZEIT_CHECKBOX,IDC_TAB_DREIECK_BESCHLEUNIGUNG_CHECKBOX,IDC_TAB_DREIECK_DREHZAHL_CHECKBOX';
g_aAvailableBoxesRotative['TRAPEZE'] = 'IDC_TAB_TRAPEZ_WINKEL_CHECKBOX,IDC_TAB_TRAPEZ_ZEIT_CHECKBOX,IDC_TAB_TRAPEZ_BESCHLEUNIGUNG_CHECKBOX,IDC_TAB_TRAPEZ_DREHZAHL_CHECKBOX';

// associative array from tabulator type to maximum number of possible checkboxes
var g_aMaxNumberRotative = {};
g_aMaxNumberRotative['SINGLE'] = '2';
g_aMaxNumberRotative['TRIANGLE'] = '2';
g_aMaxNumberRotative['TRAPEZE'] = '3';

// associative array from tabulator type to checkboxes that must be always set
var g_aCheckAlwaysRotative = {};
g_aCheckAlwaysRotative['WAIT'] = 'IDC_TAB_BEWEGUNG_ZEIT_CHECKBOX';
g_aCheckAlwaysRotative['OTHER_MOTION'] = 'IDC_TAB_BEWEGUNG_ZEIT_CHECKBOX';


// -------------------------------------------------------------------------------------------------------------------------------------------------
// functions that get called from outside
// -------------------------------------------------------------------------------------------------------------------------------------------------

/**
 * initialises the ui according to checkbox settings
 *
 * @param MPType {string} - type of motion profile
 */
function InitProfileUI( MPType )
{
	// special handling for single phase dependent from phase type
	
	var strPhaseType = GetCurrentPhaseType( GetPhaseComboID() );
	DisableBoxes( strPhaseType, MPType );

	// enable/disable edits and combos corresponding to checkbox settings
	var ids;
	var aIDs = GetIDArray( MPType );
	for ( var checkbox in aIDs ) 
	{
		if ( typeof( checkbox ) != 'string' )
			continue;
			
		ids = aIDs[checkbox].split( ',' );

		if ( IsChecked( checkbox ) )
			EnableValues( ids[0], ids[1], 'true' );
		else EnableValues( ids[0], ids[1] );
	}
}


/**
 * handling of checkbox presses
 *
 * @param ID {string} - id of checkbox that evokes this function
 * @param MPType {string} - type of motion profile
 */
function OnCheckbox( ID, MPType )
{
	// test if too many checks are set and uncheck all, if needed
	var TabID = FindTabForBox( ID, MPType );
	if ( !TestCount( TabID, MPType ) )
	{
		UncheckAll( TabID, MPType );
		document.getElementById( ID ).checked = 'true';
	}

	// enable/disable corresponding edits and combox
	var ids = GetIDArray( MPType )[ID];
	if ( ids )
	{
		ids = ids.split( ',' );
		if ( IsChecked( ID ) )
			EnableValues( ids[0], ids[1], 'true' );
		else EnableValues( ids[0], ids[1] );
	}
}


/**
 * phase type has changed
 *
 * @param ID {string} - id of combo box that evokes this function
 * @param MPType {string} - type of motion profile
 */
function OnPhaseTypeChange( ID, MPType )
{
	// enable/disable boxes based on current selected phase type
	var strPhaseType = GetCurrentPhaseType( ID );
	DisableBoxes( strPhaseType, MPType );

	// test if too many checks are set and uncheck all, if needed
	var TabID = 'SINGLE';
	if ( !TestCount( TabID, MPType ) )
		UncheckAll( TabID, MPType )
}


// -------------------------------------------------------------------------------------------------------------------------------------------------
// functions for doing the main work
// -------------------------------------------------------------------------------------------------------------------------------------------------


/**
 * enables/disables the checkboxes respective to the selected phase type
 *
 * @param strPhaseType {string} - current phase type for single phase
 * @param MPType {string} - type of motion profile
 */
function DisableBoxes( strPhaseType, MPType )
{
	// enable all boxes for single phase
	var boxes = GetAvailableBoxes( MPType )['SINGLE'].split( ',' );
	for( var i = 0; i < boxes.length; i++ )
		document.getElementById( boxes[i] ).disabled = null;

	// disable all boxes for specified phase
	var BoxIDs = GetPhaseBoxes( MPType )[strPhaseType].split( ',' );
	var ids;
	for( i = 0; i < BoxIDs.length; i++ )
	{
		if ( BoxIDs[i] != '' )
		{
			document.getElementById( BoxIDs[i] ).checked = null;
			document.getElementById( BoxIDs[i] ).disabled = 'true';
			ids = GetIDArray( MPType )[BoxIDs[i]].split( ',' );
			if ( ids.length == 2 )
			{
				// disable corresponding edit/combo
				EnableValues( ids[0], ids[1] );
			}
		}
	}

	// check all boxes that must always be checked
	var id = GetCheckAlways( MPType )[strPhaseType];
	if ( id && ( id != '' ) )
	{
		document.getElementById( id ).disabled = null;
		document.getElementById( id ).checked = 'true';
		ids = GetIDArray( MPType )[ id ].split( ',' );
		if ( ids.length == 2 )
		{
			// enable corresponding edit/combo
			EnableValues( ids[0], ids[1], 'true' );
		}
	}
}


/**
 * find the corresponding tab for a checkbox id
 *
 * @param BoxID {string} - id of checkbox for which to find the corresponding tab
 * @param MPType {string} - type of motion profile
 *
 * @return string - id of tab page
 */
function FindTabForBox( BoxID, MPType )
{
	var ids;
	var TabID;

	// this could also be done by making an additional associative array from check box id
	// to corresponding tab
	// advantage : faster, disadvantage : duplicate knowledge, more memory stressing
	// since time efficiency is no issue for EasyKat anyway, I choose to stick with one 
	// associative array only and do the finding by algorithm

	for( var tab in GetAvailableBoxes( MPType ) )
	{
		ids = GetAvailableBoxes( MPType )[tab].split( ',' );
		for( i = 0; i < ids.length; i++ )
		{
			if (  BoxID == ids[i] )
			{
				TabID = tab;
				break;
			}
		}
	}

	return( TabID );
}


/**
 * tests, if the number of checkboxes checked on this page is bigger than the maximum allowed number of boxes on this page
 *
 * @param TabID {string} - id of page 
 * @param MPType {string} - type of motion profile
 *
 * @return boolean - true : checked
 *                   false: not checked
 */
function TestCount( TabID, MPType )
{
	// count checked boxes on this page
	var nCount = 0;
	var ids = GetAvailableBoxes( MPType )[TabID].split( ',' );
	for ( var i = 0; i < ids.length; i++ )
	{
		if ( ids[i] != '' )
		{
			if ( IsChecked( ids[i] ) )
				nCount++;
		}
	}

	// get maximum allowed number of boxes
	var nMax = GetMaxNumber( MPType )[TabID];
	if ( TabID == 'SINGLE' )
	{
		// if single page and constant or wait phase, only one check is allowed
		var strPhaseType = GetCurrentPhaseType( GetPhaseComboID() );
		ids = GetPhaseBoxes( MPType )[strPhaseType].split( ',' );
		if ( ids.length > 1 ) 
			nMax = 1;
	}

	return( nCount <= nMax );
}


/**
 * unchecks all checkboxes on this tab page
 *
 * @param TabID {string} - id of page 
 * @param MPType {string} - type of motion profile
 */
function UncheckAll( TabID, MPType )
{
	var BoxIDs = GetAvailableBoxes( MPType )[TabID].split( ',' );
	for ( var i = 0; i < BoxIDs.length; i++ )
	{
		if ( BoxIDs[i] != '' )
		{
			// uncheck box
			document.getElementById( BoxIDs[i] ).checked = false;
			ids = GetIDArray( MPType )[BoxIDs[i]].split( ',' );
			if ( ids.length == 2 )
			{
				// disable corresponding edit/combo
				EnableValues( ids[0], ids[1] );
			}
		}
	}
}


// -------------------------------------------------------------------------------------------------------------------------------------------------
// various small helper functions
// -------------------------------------------------------------------------------------------------------------------------------------------------

/**
 * retrieve the current selected phase type
 *
 * @param ComboID {string} - id of phase type combobox
 *
 * @return string - current phase type ID
 */
function GetCurrentPhaseType( ComboID )
{
	var strValue = document.getElementById(ComboID).value;
	return( strValue );//getComboValue( ComboID ) );
}


/**
 * checks if a specific checkbox is checked
 *
 * @param BoxID {string} - ID of checkbox to check
 *
 * @return boolean - true : checked
 *                   false: not checked
 */
function IsChecked( BoxID )
{
	return( document.getElementById( BoxID ).checked );
}


/**
 * enables/disables the edit and combos respective to the state of the corresponding checkbox
 *
 * @param EditID {string} - id of edit box to enable/disable
 * @param ComboID {string} - id of combobox to enable/disable
 * @param enable {string or null/undefined} - enable or disable(if null/undefined) IDs
 */
function EnableValues( EditID, ComboID, enable )
{
	var disabled; 
	if ( !enable )
	{
		document.getElementById( EditID ).disabled = 'true';
		document.getElementById( ComboID ).disabled = 'true';
	}
	else
	{
		document.getElementById( EditID ).disabled = null;
		document.getElementById( ComboID ).disabled = null;
	}
}


/**
 * get actual associative array from checkbox id to id's of associated edit field and combobox, based on type of motion profile
 *
 * @param MPType {string} - type of motion profile
 *
 * @return array - ID array for linear or rotative motion profile, based on the profile type
 */
function GetIDArray( MPType )
{
	var aIDArray = g_aIDArrayLinear;
	if ( IsRotative( MPType ) )
		aIDArray = g_aIDArrayRotative;

	return( aIDArray );
}


/**
 * get actual associative array from phase type to id's of associated check boxes that must be disabled in this phase, based on type of motion profile
 *
 * @param MPType {string} - type of motion profile
 *
 * @return array - array for linear or rotative motion profile, based on the profile type
 */
function GetPhaseBoxes( MPType )
{
	var aPhaseBoxes = g_aPhaseBoxesLinear;
	if ( IsRotative( MPType ) )
		aPhaseBoxes = g_aPhaseBoxesRotative;

	return( aPhaseBoxes );
}


/**
 * get actual associative array from tabulator type to available checkboxes, based on type of motion profile
 *
 * @param MPType {string} - type of motion profile
 *
 * @return array - array for linear or rotative motion profile, based on the profile type
 */
function GetAvailableBoxes( MPType )
{
	var aAvailableBoxes = g_aAvailableBoxesLinear;
	if ( IsRotative( MPType ) )
		aAvailableBoxes = g_aAvailableBoxesRotative;

	return( aAvailableBoxes );
}


/**
 * get actual associative array from tabulator type to maximum number of possible checkboxes, based on type of motion profile
 *
 * @param MPType {string} - type of motion profile
 *
 * @return array - array for linear or rotative motion profile, based on the profile type
 */
function GetMaxNumber( MPType )
{
	var aMaxNumber = g_aMaxNumberLinear;
	if ( IsRotative( MPType ) )
		aMaxNumber = g_aMaxNumberRotative;

	return( aMaxNumber );
}


/**
 * get actual associative array from tabulator type to checkboxes that must be always set, based on type of motion profile
 *
 * @param MPType {string} - type of motion profile
 *
 * @return array - array for linear or rotative motion profile, based on the profile type
 */
function GetCheckAlways( MPType )
{
	var aCheckAlways = g_aCheckAlwaysLinear;
	if ( IsRotative( MPType ) )
		aCheckAlways = g_aCheckAlwaysRotative;

	return( aCheckAlways );
}


/**
 * get ID of phase type combobox
 *
 * @return string - requested ID
 */
function GetPhaseComboID()
{
	return( 'IDC_PHASENTYP_COMBO' );
}


/**
 * checks if type is a rotative motion profile type
 *
 * @param MPType {string} - type of motion profile
 *
 * @return boolean - true : rotative motion profile
 *                   false : linear motion profile
 */
function IsRotative( MPType )
{
	return( MPType == 'ROTATIVE' );
}


// -------------------------------------------------------------------------------------------------------------------------------------------------
// functions for power-on time profiles only
// -------------------------------------------------------------------------------------------------------------------------------------------------

/**
 * calculates the sum of all inserted power-on times
 */
function calculatePOTSum()
{
    var accelerationCtrl = document.getElementById( 'IDC_BESCHLEUNIGUNG_ONTIME_EDIT' );
    var brakeCtrl = document.getElementById( 'IDC_VERZOEGERUNG_ONTIME_EDIT' );
    var speedCtrl = document.getElementById( 'IDC_EILGANG_ONTIME_EDIT' );
    var workCtrl = document.getElementById( 'IDC_VERARBEITUNG_ONTIME_EDIT' );
    var wwpCtrl = document.getElementById( 'IDC_STILLSTAND_KRAFT_ONTIME_EDIT' );
    var wwopCtrl = document.getElementById( 'IDC_STILLSTAND_OHNE_KRAFT_ONTIME_EDIT' );
    var acceleration_time = ( accelerationCtrl ? parseInt( accelerationCtrl.value, 10 ) : 0 );
    if ( isNaN( acceleration_time ) )
        acceleration_time = 0;
    var brake_time = ( brakeCtrl ? parseInt( brakeCtrl.value, 10 ) : 0 );
    if ( isNaN( brake_time ) )
        brake_time = 0;
    var speed_time = ( speedCtrl ? parseInt( speedCtrl.value, 10 ) : 0 );
    if ( isNaN( speed_time ) )
        speed_time = 0;
    var work_time = ( workCtrl ? parseInt( workCtrl.value, 10 ) : 0 );
    if ( isNaN( work_time ) )
        work_time = 0;
    var wwp_time = ( wwpCtrl ? parseInt( wwpCtrl.value, 10 ) : 0 );
    if ( isNaN( wwp_time ) )
        wwp_time = 0;
    var wwop_time = ( wwopCtrl ? parseInt( wwopCtrl.value, 10 ) : 0 );
    if ( isNaN( wwop_time ) )
        wwop_time = 0;
    
    var sum = acceleration_time + brake_time + speed_time + work_time + wwp_time + wwop_time;
    var sumCtrl = document.getElementById( 'IDC_SUMME_ONTIME_EDIT' );
    if ( sumCtrl )
        sumCtrl.value = '' + sum;
}