/**
 * common AJAX functions for IndraSize
 *
 * Remember: the following functions work only if Prototype V1.6.0 (or above) is included
 *
 * @category client UI
 * @package core
 * @copyright  Copyright (c) 2011 Plan Software GmbH (http://www.plansoft.de)
 */

 if ( typeof( ajaxHelper ) === 'undefined' )
	ajaxHelper = {};

/**
 * serialize the current form's elements to a query string
 *
 * shamelessly copied from Prototype JavaScript framework, version 1.6.0.3 (c) 2005-2008 Sam Stephenson
 * and modified for own purposes
 *
 * @params options - object with optional modification
 *                          hash: return query string representation or object
 *                          submit:
**/
ajaxHelper.serializeForm = function( options )
{
	var elements = Form.getElements( document.forms[0] );
    if ( typeof options !== 'object' ) 
        options = { hash: !!options };
    else if ( Object.isUndefined( options.hash ) ) 
        options.hash = true;
        
    var key, value, submitted = false, submit = options.submit;
    var data = elements.inject( { }, function( result, element ) 
    {
        if ( !element.disabled && element.name ) 
        {
		    key = element.name;
		    if ( element.type === 'checkbox' )	// EasyGUI special submit for checkboxes
			    value = $(element).checked;
		    else
            {
                value = $(element).getValue();
                if ( ( element.type === 'radio' ) && ( value === '' ) )	// EasyGUI special submit for radiobuttons
                    return result;
            }
            if ( value && element.type !== 'file' && ( element.type !== 'submit' || ( !submitted &&
                 submit !== false && ( !submit || key == submit ) && ( submitted = true ) ) ) ) 
            {
                if ( key in result ) 
                {
                    // a key is already present; construct an array of values
                    if ( !Object.isArray( result[key] ) )
				        result[key] = [result[key]];
                    result[key].push( value );
                }
                else result[key] = value;
            }
		}
		return result;
    } );

    return( options.hash ? data : Object.toQueryString( data ) );
  }


/**
 * issue an asynchronuous AJAX request to the server
 *
 * @param url - ajax request url (required)
 * @param element - element on which a user action issued the request (may be null)
 * @param bSubmitFormData - submit complete form data with the request
 * @param additionalSubmitVars - additonal vars: single additional var (form id=text) or array of additional vars to submit (may be null)
 * @param successHandlerFn - success handler function (required - must not be null)
 * @param successHandlerParams - additional params for the success handler function (optional)
 * @param failureHandlerFn - failure handler function (optional)
 */
ajaxHelper.startRequest = function( url, element, bSubmitFormData, additionalSubmitVars, successHandlerFn, successHandlerParams, failureHandlerFn )
{
	// preserve submit event
	var objSubmit = $( 'EKSUBMITEVENT' );

	if ( objSubmit && element ){
		if ( typeof( element ) === 'string' )
			objSubmit.value = element;
		else objSubmit.value = element.id;
	}

	// get content variables of actual HTML form
	var form_data = ''; 
	if ( bSubmitFormData )
		form_data = ajaxHelper.serializeForm();
	else
	{	
		// we always need state id and session id (at least for testing the client-side stuff with firebug)
		var state = $( 'stateid' );
		if ( state )
			form_data += '&stateid=' + $( state ).getValue();
		var session = $( 'sessionid' );
		if ( session )
			form_data += '&sessionid=' + $( session ).getValue();
		form_data += '&SUBMITTOSTORE=NO';
	}
	if ( !objSubmit && element ){
		if ( typeof( element ) === 'string' )
			form_data += '&EKSUBMITEVENT=' + element;
		else form_data += '&EKSUBMITEVENT=' + element.id;
	}

	if ( element && ( typeof( element ) === 'object' ) )
	{
		if ( element.type === 'radio' )
			form_data += '&CHANGEDCTRLID=' + element.name;
		else form_data += '&CHANGEDCTRLID=' + element.id;
	}

	// add additional variables
	if ( typeof( additionalSubmitVars ) === 'array' )
	{
		for( var i = 0; i < additionalSubmitVars.length; i++ )
		{
			if ( ( ( typeof( additionalSubmitVars[i] ) === 'string' ) && ( additionalSubmitVars[i].charAt( 0 ) !== '&' ) ) ||
				 ( typeof( additionalSubmitVars[i] ) !== 'string' ) )
				form_data += '&';
			form_data += additionalSubmitVars[i];
		}
	}
	else if ( typeof( additionalSubmitVars ) === 'object' ) 
	{
		for( var name in additionalSubmitVars )
 		{
			form_data += '&';
			form_data += name;
			form_data += '=';
			form_data += additionalSubmitVars[name];
		}
	}
	else if ( additionalSubmitVars ) 
	{	
		if ( ( ( typeof( additionalSubmitVars ) === 'string' ) && ( additionalSubmitVars.charAt( 0 ) !== '&' ) ) ||
			 ( typeof( additionalSubmitVars ) !== 'string' ) )
			form_data += '&';
		form_data += additionalSubmitVars;
	}

	// issue ajax 'post'-request
	new Ajax.Request( url,
	{
		// send form variables and other submit variables as post parameter
		parameters: {
			'__eksubmit_values__' : form_data
		},

		onSuccess: function( transport ) 
		{
			// if we have a valid success handler, call it with the ajax response
			if ( successHandlerFn && typeof( successHandlerFn ) === 'function' )
			{
				var response = '';
				try
				{
					if ( transport.responseText.charAt(0) === '[' || transport.responseText.charAt(0) === '{' )	// looks like a JSON string
						response = eval( '(' + transport.responseText + ')' );
					else response = transport.responseText;														// normal string content
				}
				catch( e )
				{
					// ... but wasn't a JSON string
					response = transport.responseText;
				}
				//alert( response );
				successHandlerFn( response, successHandlerParams );
			}
		},

		onFailure: function( transport ) 
		{
			if ( parent && parent.dialog )
				parent.dialog.enable();
			else dialog.enable();
			
			// if we have a valid failure handler, call it with the ajax response
			if ( failureHandlerFn && ( typeof( failureHandlerFn ) === 'function' ) )
			{
				var response = transport.responseText;
				//alert( response );
				failureHandlerFn( response );
			}
		}
	} );
}


