/**
 * common table helper functions for IndraSize
 *
 * Remember: the following functions work only if Prototype V1.6.0 (or above) is included
 *
 * @category client UI
 * @package core
 * @copyright  Copyright (c) 2011 Plan Software GmbH (http://www.plansoft.de)
 */

 if ( typeof( tableHelper ) === 'undefined' )
	tableHelper = {};

/**
 * clear table content
 *
 * @param strTableID - id of table
 * @param bFull - full search(true) / direct selection (false)
 */
tableHelper.clearTable = function( strTableID, bFull )
{
	var elTable = dialog[strTableID];				// this results in the EasyGUI element
	var elTableFL = $( strTableID + '_FL_TABLE' );	// this results in the DOM element
	if ( !elTable || !elTableFL )
		return;

	// remove current selection
	elTable.selected = '';
	elTable.element.setAttribute( 'selected', '' );
	elTable.reset();
	
	// remove all rows except the header (and for full search the row for the technical data)
	var fixedLines = ( bFull ? 1 : 0 );
	for ( var i = elTable.element.rows.length - 1; i > fixedLines; --i ) 
		elTable.element.down().removeChild( elTable.element.rows[i] );

	for ( var i = elTableFL.rows.length - 1; i > fixedLines; --i ) 
		elTableFL.down().removeChild( elTableFL.rows[i] );
}


/**
 * (re)build the table header
 *
 * @param strTableID - id of table
 * @param aHeader - new table header
 */
tableHelper.buildTableHeader = function( strTableID, aHeader )
{
	var elTable = dialog[strTableID];				// this results in the EasyGUI element
	var elTableFL = $( strTableID + '_FL_TABLE' );	// this results in the DOM element
	if ( !elTable || !elTableFL )
		return;
	
	// reset the whole table first
	elTable.reset();
	
	// we must make sure that the header row contains exactly as much cells as needed
	if ( elTable.element.rows[0].cells.length < aHeader.length )
	{
		// add cells (don't forget to adjust the cell style of the new cells)
		var nPresentCells = elTable.element.rows[0].cells.length;
		var nCount = aHeader.length - nPresentCells;
		var headerTextColor = elTable.element.rows[0].cells[0].readAttribute( 'headertextcolor' ) || elTable.element.readAttribute( 'headertextcolor' );
		var headerBgColor	= elTable.element.rows[0].cells[0].readAttribute( 'headerbackgroundcolor' ) || elTable.element.readAttribute( 'headerbackgroundcolor' );
		var headerFont 		= elTable.element.rows[0].cells[0].readAttribute( 'headerfont' ) || elTable.element.readAttribute( 'headerfont' );
		var headerFontSize 	= elTable.element.rows[0].cells[0].readAttribute( 'headerfontsize' ) || elTable.element.readAttribute( 'headerfontsize' );
		var headerFontWeight= elTable.element.rows[0].cells[0].readAttribute( 'headerfontweight' ) || elTable.element.readAttribute( 'headerfontweight' );
		var headerFontStyle = elTable.element.rows[0].cells[0].readAttribute( 'headerfontstyle' ) || elTable.element.readAttribute( 'headerfontstyle' );
		var headerAlign 	= elTable.element.rows[0].cells[0].readAttribute( 'headerhorizontalalign' ) || elTable.element.readAttribute( 'headerhorizontalalign' );
		var headerValign 	= elTable.element.rows[0].cells[0].readAttribute( 'headerverticalalign' ) || elTable.element.readAttribute( 'headerverticalalign' );
		var cell;
		var title = elTable.element.rows[0].cells[0].title;
		var _adjustHeaderCell = function( nCellNumber, bInFL )
		{
			cell.className = 'textTableHeader header';
			if ( headerTextColor )
				cell.style.color = headerTextColor;						
			if ( headerBgColor )
				cell.style.backgroundColor = headerBgColor;
			if ( headerFont )
				cell.style.fontFamily = headerFont;
			if ( headerFontSize )
				cell.style.fontSize = headerFontSize + 'pt';
			if ( headerFontWeight )
				cell.style.fontWeight = headerFontWeight;
			if ( headerFontStyle )
				cell.style.fontStyle = headerFontStyle;
			if ( headerAlign )
				cell.style.textAlign = headerAlign;
			if ( headerValign )
				cell.style.verticalAlign = headerValign;
			cell.style.backgroundRepeat = 'no repeat';
			cell.style.backgroundPosition = 'right center';
			if ( bInFL )
				cell.id = strTableID + 'COL' + nCellNumber + '_FL';
			else cell.id = strTableID + 'COL' + nCellNumber;
			cell.setAttribute( 'sortable', true );
			cell.title = title;
		}
		
		for( var i = 0; i < nCount; ++i )
		{
			cell = elTable.element.rows[0].insertCell( -1 );
			_adjustHeaderCell( elTable.element.rows[0].cells.length );
			//cell = elTable.columnHeader.headerTable.rows[0].insertCell( -1 );
			//_adjustHeaderCell( elTable.columnHeader.headerTable.rows[0].cells.length );
		}
		
		for( i = 0; i < nCount; ++i )
		{
			cell = elTableFL.rows[0].insertCell( -1 );
			_adjustHeaderCell( elTableFL.rows[0].cells.length, true );
		}
		
		// correct all tooltips
		for( i = 0; i < nPresentCells; ++i )
		{
			cell = elTable.element.rows[0].cells[i];
			cell.title = title;
			cell = elTableFL.rows[0].cells[i];
			cell.title = title;
		}
	}
	else if ( elTable.element.rows[0].cells.length > aHeader.length )
	{
		// delete surplus cells
		var nCount = elTable.element.rows[0].cells.length - aHeader.length;
		for( var i = 0; i < nCount; ++i )
		{
			elTable.element.rows[0].deleteCell( 0 );
			//elTable.columnHeader.headerTable.rows[0].deleteCell( 0 );
			elTableFL.rows[0].deleteCell( 0 );
		}
	}

	// now fill the new header texts
	elTable.sortTitle = elTable.element.rows[0].cells[0].title;
	elTableFL.title = elTable.element.rows[0].cells[0].title;
	var nCount = aHeader.length, cellIdx;
	for( var i = 0; i < nCount; ++i )
	{
		cellIdx = elTable.element.rows[0].cells[i].cellIndex;
		//elTable.columnHeader.headerTable.rows[0].cells[cellIdx].innerHTML = aHeader[i];
		//elTable.columnHeader.headerTable.rows[0].cells[cellIdx].setAttribute( 'text', aHeader[i] );
		elTable.element.rows[0].cells[cellIdx].innerHTML = aHeader[i];
		elTable.element.rows[0].cells[cellIdx].setAttribute( 'text', aHeader[i] );
		cellIdx = elTableFL.rows[0].cells[i].cellIndex;
		elTableFL.rows[0].cells[cellIdx].innerHTML = aHeader[i];
		elTableFL.rows[0].cells[cellIdx].setAttribute( 'text', aHeader[i] );
	}
}


/**
 * append drive data to the table (each drive forms a row in the table)
 *
 * @param strTableID - id of table
 * @param aDrives - drive data to append
 */
tableHelper.appendToTable = function( strTableID, aDrives )
{
	var elTable = dialog[strTableID];				// this results in the EasyGUI element
	var elTableFL = $( strTableID + '_FL_TABLE' );	// this results in the DOM element
	if ( !elTable || !elTableFL )
		return;
		
	// append new row
	var aDrive, row, cell, text, nAttributes, nRowNumber;
	var nDrives = aDrives.length;
	var _appendToTable = function( table )
	{	
		for ( var i = 0; i < nDrives; ++i )
		{
			row = table.insertRow( -1 );
			nRowNumber = table.rows.length - 2;	// first row is the header row for EasyGUI tables
			row.addClassName( 'selectable' );
			if ( ( nRowNumber % 2 ) === 0 )
				row.addClassName( 'altrow' );
			row.id = strTableID + '_' + nRowNumber;
			row.setAttribute( 'selected', false );
			
			aDrive = aDrives[i];
			nAttributes = aDrive.length;
			for( var j = 0; j < nAttributes; ++j )
			{
				cell = row.insertCell( -1 );
				cell.id = row.id + '_' + j;
				cell.addClassName( 'tabBorder' );
				cell.innerHTML = aDrive[j];
				cell.setAttribute( 'text', aDrive[j] );
			}
		}
	}
	
	_appendToTable( elTable.element );
	_appendToTable( elTableFL );
	elTable.render();
}


/**
 * select a row in the table
 *
 * @param strTableID - id of table
 * @param nRow - number of row (0-based)
 */
tableHelper.selectRow = function( strTableID, nRow )
{
	var elTable = dialog[strTableID];
	if ( elTable && ( nRow > -1 ) )
		elTable.selectRow( strTableID + '_' + nRow );
}

