/**
 * @category   settings
 * @package    Core
 * @copyright  Copyright (c) 2010 Plan Software GmbH (http://www.plansoft.de)
 */

// building the namesapce
if ( typeof( Base ) == "undefined" )
	Base = {};


/**
 * get name and path of inifile where the settings page are stored
 *
 * @return string - inifile path+name
 */
Base.getIniFilenameForSettings = function()
{
	return( getinipath() );
}


/**
 * read a value from the inifile and set it to the store
 *
 * @param storeVar - store variable to set
 * @param storePath - store path where to set variable
 * @param iniFilename - filename of inifile
 * @param iniSection - section of variable in inifile
 * @param iniVar - key of variable in inifile
 * @param defaultVal - default value for variable in inifile
 */
Base.setFromIni = function( storeVar, storePath, iniFilename, iniSection, iniVar, defaultVal )
{
	var strRet = readinistring( iniFilename, iniSection, iniVar );
	if ( strRet == "" )
		strRet = defaultVal;
	setstring( storeVar, storePath, strRet );
}


/**
 * reads settings from inifile to the store. This bubble handles only inifile settings that definitively must be present at first script startup.
 * All settings are still correctly loaded in C++ code and managed there
 *
 * @param strPathData  - store path of settings data
 */
Base.readSettingsFromIni = function( strPathData )
{
	var strInifile = Base.getIniFilenameForSettings();
	
	// settings for update
	var strAutomaticUpdate = readinistring( strInifile, "System", "UpdateOnStart" );
	if ( strAutomaticUpdate == "" )
		strAutomaticUpdate = "true";
	setstring( "UPDATE_ON_START",  strPathData, strAutomaticUpdate );

	// settings for disclaimer
	var strShowDisclaimer = readinistring( strInifile, "System", "ShowDisclaimerDialogOnStart" );
	if ( strShowDisclaimer == "" )
		strShowDisclaimer = "true";
	setstring( "SHOWDISCLAIMERONSTART",  strPathData, strShowDisclaimer );
}


