/**
 * @category   update
 * @package    Core
 * @copyright  Copyright (c) 2009-2010 Plan Software GmbH (http://www.plansoft.de)
 */

// building the namespace
if ( typeof( Base ) == "undefined" )
	Base = {};	

/**
 * test if one should do autoupdate on start
 *
 * @return boolean - true: perform update on start
 *                   false: don't perform update on start
 */
Base.isUpdateOnStart = function()
{
	// autoupdate only in CDROM-mode
	if ( getstring( "CATALOG.AUTOSTARTINTERNETSERVER", "ROOT" ) == "true" )
		return( false );
		
	// ... and only if set by the presets
	var strAutomaticUpdate = getstring( "UPDATE_ON_START", "PROJECT.SETTINGS" );
	return( strAutomaticUpdate == "true" );
}


/**
 * handle the autoupdate on start - functionality
 *
 * @return boolean - true: set next dialog to update dialog
 *                   false: don't change next dialog
 */
Base.handleUpdateOnStart = function()
{
	// autoupdate only in CDROM-mode
	if ( getstring( "CATALOG.AUTOSTARTINTERNETSERVER", "ROOT" ) == "true" )
		return( 0 )

	// init autoupdate variables		
	var strPathData = "AUTOUPDATE";
	var strVersion = getstring( "CATVERSION", "DLGDATA" );
	var strURL = getstring( "UPDATEURL", "DLGDATA" );
	
	// parameters for start function
	var nUpdateNewer = 0;
	var strShow = "hidden";
	var strMode = "0";
	var strStartText = "";

	// get data for update from webserver	
	var nRes = setupdatedatatostore( strURL, "indrasize", strVersion, "DE", strPathData );
	var strNewestUpdateVersion = getstring( "NEWEST_UPDATE_VERSION", strPathData );
	
	// handle events
	if ( strNewestUpdateVersion == "" )
	{
		strStartText = translate( "START_MESSAGE_NO_VERSION" );
		strMode = "1";
	}
	else 
	{
		var bCompared = true;
		var nPos = find( strNewestUpdateVersion, "." );
		var nPos2 = find( strVersion, "." );
		// version format x.y.zzz(z) - extract x, y, z 
		if ( ( nPos > -1 ) && ( nPos2 > -1 ) )
		{
			// extract primary version and compare
			var x1 = left( strNewestUpdateVersion, nPos - 1 ) - 0;
			var x2 = left( strVersion, nPos2 - 1 ) - 0;
			if ( x1 == x2 )
			{
				var nPos21 = findex( strNewestUpdateVersion, ".", nPos + 1, 1 );
				var nPos22 = findex( strVersion, ".", nPos2 + 1, 1 );
				if ( ( nPos21 > -1 ) && ( nPos22 > -1 ) )
				{
					// extract middle version and compare
					var y1 = mid( strNewestUpdateVersion, nPos + 1, nPos21 - nPos - 1 ) - 0;
					var y2 = mid( strVersion, nPos2 + 1, nPos22 - nPos2 - 1 ) - 0;
					if ( y1 == y2 )
					{
						var z1 = right( strNewestUpdateVersion, strlen( strNewestUpdateVersion ) - nPos21 ) - 0;
						var z2 = right( strVersion, strlen( strVersion ) - nPos22 ) - 0;
						if ( z1 <= z2 )
							nRes = -1;
						else nRes = 1;
					}
					else if ( y1 < y2 )
						nRes = -1;
					else nRes = 1;						
				}
				else bCompared = false;		// strange unknown format -> use standard string compare
			}				
			else if ( x1 < x2 )
				nRes = -1;
			else nRes = 1;
		}
		else bCompared = false;		// strange unknown format -> use standard string compare
		if ( !bCompared )
			nRes = strcmp( strNewestUpdateVersion, strVersion );
			
		// set message texts
		if ( nRes <= 0 )
		{
			strStartText = translate( "START_MESSAGE_NEWEST_VERSION" );
			strMode = "2";
		}
		else 
		{
			strStartText = translate( "START_MESSAGE_OLD_VERSION" );
			strMode = "3";
			nUpdateNewer = 1;
		}
	}
	
	// set start function and text
	if ( strMode === '1' )
	    setint( "UPDATE_NEWER", strPathData, 2 );
	else setint( "UPDATE_NEWER", strPathData, nUpdateNewer );
	if ( !Base.isUpdateOnStart() )
	{
		// no autoupdates if we are in CD-mode or the user has disabled autoupdates
		strShow = "hidden";
		strMode = 0;
		nUpdateNewer = 0;
		strStartText = "";
	}
	else strShow = "visible"

	var strStartFunction = "modifyStartText( 'IDC_START_MESSAGE_TEXT', '" + strShow + "', '" + strMode + "' );";
	setstring( "ON_START", strPathData, strStartFunction );
	setstring( "START_MESSAGE_TEXT", strPathData, strStartText );
			
	return( nUpdateNewer );
}


