/**
 * controller for actions concerning full motor search
 *
 * by definition of the action handlers, the current parameters transfered from the client side are located in the store.
 *
 * @category   Controller
 * @package    Core
 * @copyright  Copyright (c) 2011 Plan Software GmbH (http://www.plansoft.de)
 */

// building the namespace
if ( typeof( Controller ) === 'undefined' )
	Controller = {};	
if ( typeof( Controller.fullSearch ) === 'undefined' )
	Controller.fullSearch = {};

/**
 * action handler for prepareSearch-action on full motorsearch
 *
 * @return object - error: error occured while trying to prepare the search (may be empty)
 */
Controller.fullSearch.prepareSearchAction = function()
{
	return( Controller.prepareSearch( true ) );
}


/**
 * action handler for getMotors-action on full motorsearch
 *
 * @return object - motors: array with full motor types
 *                - error: error occured while trying to get the motor list
 */
Controller.fullSearch.getMotorsAction = function()
{
	return( Controller.getMotors( true ) );
}


/**
 * action handler for search-action on full motorsearch
 *
 * @return object - motorDataHeader: header (i.e. column names) for motor data (may be empty or missing)
 * 					motorData: array with full motor data for motor-regulator combinations from search results
 *                	error: error occured while trying to start the search (may be empty)
 */
Controller.fullSearch.searchAction = function()
{
	return( Controller.searchMotors( true ) );
}


/**
 * action handler for stopSearch-action on direct motor selection
 *
 * @return object - error: error occured while trying to stop the search (may be empty)
 */
Controller.fullSearch.stopSearchAction = function()
{
	return( Controller.stopSearch( true ) );
}


