/**
 * core handler for incoming requests - this handler is called for every request (may it be an ajax request, en easygui request or ...) 
 * before any request processing in C++ is performed
 *
 * @category   handler
 * @package    Core
 * @copyright  Copyright (c) 2011 Plan Software GmbH (http://www.plansoft.de)
 */
 
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Input:
// PATH		 	= Pfad bzw. die URL
// HEADER 		= Request-Header
// CONTENT		= Request-Content (kann auch leer sein)
// 
// Output:
// RESULT		= Response (Content)
// MIMETYPE		= Response Mime-Type also z.B. text/plain (default), text/html, text/xml, ...
//
// return 1		= Request wurde hier verarbeitet
// return 0		= Normaler EasyKat Request

#include "Controller/*.b"

/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// main handler

{
	// easygui requests are handled within the catalog
	if ( ( PATH === '/easygui.php' ) || ( PATH === '/easygui.plso' ) || ( PATH === '/' ) )
		return( 0 );
		
	var nRequestHandled = 0;
	var bHandlerStartsWithSlash = ( PATH.charAt( 0 ) === '/' );
	var handler = PATH.split( '/' );
	
	// determine if we have a valid ajax request
	var bStartHandler = false;
	if ( bHandlerStartsWithSlash )
		bStartHandler = ( ( handler.length >= 4 ) && ( handler[0] === '' ) && ( handler[1] === 'ajax' ) );
	else bStartHandler = ( ( handler.length >= 3 ) && ( handler[0] === 'ajax' ) );
	
	// for ajax requests, call the appropriate controller and controller action handler
	if ( bStartHandler )
	{
		// submit complete form content to store
		if ( CONTENT.indexOf( '__eksubmit_values__' ) > -1 )
		{
			initdlgvars( CONTENT );
			// &SUBMITTOSTORE=NO is set by the ajax request composer if the form data are not posted. In this case, we either have no post data at all, or 
			// we handle them directly with the current dlgvars
			if ( CONTENT.indexOf( '%26SUBMITTOSTORE%3DNO' ) < 0 )
				ekstoragesubmit();
		}
		
		// evaluate handler function
		var strActionFun = 'Controller.';
		if ( bHandlerStartsWithSlash )
			strActionFun += handler[2];
		else strActionFun += handler[1];
		strActionFun += '.';
		if ( bHandlerStartsWithSlash )
			strActionFun += handler[3];
		else strActionFun += handler[2];
		strActionFun += 'Action';
		
		var fn;
		try {
			// simple tests to prevent (some) code injection attacks
			if ( ( strActionFun.length < 200 ) && ( strActionFun.search( /[\\\+\{\}\[\]\*\^\$\?\{\}-]/ ) < 0 ) )
				fn = eval( strActionFun );
			else logtrace( '\n HANDLE_REQUEST.b --- function descriptor ' + strActionFun + ' is too long or suspect to script injection attacks, request rejected\n' );
		}
		catch( e ) {
			logtrace( '\n HANDLE_REQUEST.b --- Error on evaluating function descriptor ' + strActionFun + ' :' + e.message + ' , request rejected\n' );
		}

		// dispatch function
		if ( fn && ( typeof( fn ) === 'function' ) )
		{
			try {
				RESULT = fn();
				nRequestHandled = 1;
			}
			catch( e ) {
				logtrace( '\n HANDLE_REQUEST.b --- Error on dispatching function ' + strActionFun + ' :' + e.message + '\n' );
			}
		}
	}
	
	return( nRequestHandled );
}