/**
 * @category   dialog control
 * @package    Core
 * @copyright  Copyright (c) 2001-2010 Plan Software GmbH (http://www.plansoft.de)
 */

#include "Base.update.b"
#include "Base.settings.b"


// building the namespace
if ( typeof( Control ) == "undefined" )
	Control = {};	

/**
 * calculates the dialog id for the next mechanics dialog
 *
 * @param CurrentDlg - actual dialog id
 *
 * @return next mechanics dialog id
 */
Control._getMechanicsDlg = function( CurrentDlg )
{
   	var NewDlg = CurrentDlg;
	var MechanicsID = getstring( "MECHANICS", "DLGDATA.DLGVARS.IDD_APPLICATION_SELECTION" );	// actual mechanics id
	if ( MechanicsID == "CRotaryKnifeController" )
        NewDlg = "IDD_MECHANICS_ROTARY_KNIFE";
	else if ( MechanicsID == "CRollerFeedController" )
        NewDlg = "IDD_MECHANICS_ROLLER_FEED";
    else NewDlg = "IDD_MECHANICS";

	return( NewDlg );
}


/**
 * calculates the dialog id for the next motion profile dialog
 *
 * @param CurrentDlg - actual dialog id
 *
 * @return next motion profile dialog id
 */
Control._getMotionProfileDlg = function( CurrentDlg )
{
	var NewDlg = CurrentDlg;

	var MotionProfileType = getstring( "MOTION_PROFILE_TYPE", "DLGDATA.DLGVARS" );	// actual type of motion profile
	if ( ( MotionProfileType == "LINEAR" ) || ( MotionProfileType == "" ) )		// that's only for debugging purposes
		NewDlg = "IDD_MOTION_PROFILE";
	else if ( MotionProfileType == "FLYING_CUTOFF" )
		NewDlg = "IDD_MOTION_PROFILE_FLYING_CUTOFF";
	else if ( MotionProfileType == "ROTARY_KNIFE" )
		NewDlg = "IDD_MOTION_PROFILE_ROTARY_KNIFE";
	else if ( MotionProfileType == "ROTATIVE" )
		NewDlg = "IDD_MOTION_PROFILE_ROTATIVE";
	else if ( MotionProfileType == "WINDER" )
		NewDlg = "IDD_MOTION_PROFILE_WINDER";
	else if ( MotionProfileType == "ROLL_FEED_INTERMITTED" )
		NewDlg = "IDD_MOTION_PROFILE_ROLL_FEED";
	else if ( MotionProfileType == "RELATIVE_POT" )
	{
		// type of relative power-on-time also dep}s on the current search list type
		var searchlisttype = getstring( "SEARCH_LIST_TYPE", "DLGDATA.DLGVARS" );		// actual type of search list
		if ( ( searchlisttype == "ROTATIVE" ) || ( searchlisttype == "" ) )	// that's only for debugging purposes
		{
			var MechanicsID = getstring( "MECHANICS", "DLGDATA.DLGVARS.IDD_APPLICATION_SELECTION" );	// actual mechanics id
			if ( MechanicsID == "CRotaryDriveController" )
				NewDlg = "IDD_RELATIVE_ONTIME_ROTARY_DRIVE";
			else NewDlg = "IDD_RELATIVE_ONTIME_ROTATIVE";
		}
		else if ( searchlisttype == "LINEAR" )
			NewDlg = "IDD_RELATIVE_ONTIME_LINEAR";
	}

	return( NewDlg );
}


/**
 * calculates the dialog id for the next motor search dialog
 *
 * @param CurrentDlg - actual dialog id
 *
 * @return next motor search dialog id
 */
Control._getMotorSearchDlg = function( CurrentDlg )
{
	var NewDlg = CurrentDlg;

	var searchlisttype = getstring( "SEARCH_LIST_TYPE", "DLGDATA.DLGVARS" );		// actual type of search list
	//print searchlisttype
	if ( ( searchlisttype == "ROTATIVE" ) || ( searchlisttype == "" ) )	// that's only for debugging purposes
	{
	    // type of selection dep}s on type of mechanics
		NewDlg = "IDD_MOTORSEARCH_ROTATIVE";
		var MechanicsID = getstring( "MECHANICS", "DLGDATA.DLGVARS.IDD_APPLICATION_SELECTION" );	// actual mechanics id
		if ( MechanicsID == "CRotaryKnifeController" )
    		NewDlg = "IDD_MOTORSEARCH_ROTARY_KNIFE";
	}
	else if ( searchlisttype == "LINEAR" )
		NewDlg = "IDD_MOTORSEARCH_LINEAR";
	else if ( searchlisttype == "S1" )
		NewDlg = "IDD_MOTORSEARCH_S1";
	else if ( searchlisttype == "MAIN_SPINDLE" )
		NewDlg = "IDD_MOTORSEARCH_MAIN_SPINDLE";

	return( NewDlg );
}


/**
 * calculates the dialog id for the start dialog for motor searching
 *
 * @param CurrentDlg - actual dialog id
 * @param Event - actual event
 *
 * @return start dialog id
 */
Control._getSelectionStartDlg = function( CurrentDlg, Event )
{
	var NewDlg = CurrentDlg;

	if ( Event == "IDC_DIREKTE_ANTRIEBSAUSWAHL_BUTTON" )
		NewDlg = "IDD_DIRECT_SELECTION";
	else if ( Event == "IDC_ANTRIEBSBERECHNUNG_BUTTON" )
		NewDlg = "IDD_APPLICATION_SELECTION";
	else 
	{
		var SelectionType = getstring( "SELECTION_TYPE","DLGDATA.DLGVARS" );	// actual type of selection
		if( SelectionType == "DIRECT" )			
			NewDlg = "IDD_DIRECT_SELECTION";
		else if( ( SelectionType == "FULL_AXIS" ) || ( SelectionType == "" ) )
			//NewDlg = "IDD_MECHANICS"
			NewDlg = Control._getMechanicsDlg( CurrentDlg );
	}

	return( NewDlg );
}


// ==================================================================================
// main process handling
// ==================================================================================

{
			
	var current_dlg	= getstring( "AKTUELLE_MASKE", "" );	// ID of actual dialog
	var event = getstring( "EKSUBMITEVENT", "" );			// event from actual dialog
	
	var start_dlg = "IDD_MAIN";
	var new_dlg = current_dlg;
	
	// ================================================================================================
	// INITIALIZE MAIN
	
	if ( current_dlg == "" )
		new_dlg = start_dlg;

	// ================================================================================================
	// additional actions for auto update
	// ================================================================================================
	setstring( "ONLINE", "DLGDATA", getstring( "CATALOG.AUTOSTARTINTERNETSERVER", "ROOT" ) );
	setstring( "UPDATEURL", "DLGDATA", getstring( "CATALOG.CATVERSION.UPDATEURL", "ROOT" ) );
    setstring( "CATVERSION", "DLGDATA", getstring( "CATALOG.INTERNAL.CATVERSION", "ROOT" ) );

	// ================================================================================================
	// special script actions for first application start
	// ================================================================================================
	if ( getstring( "AFTER_FIRST_START", "" ) == "" )
	{
		setstring( "AFTER_FIRST_START", "", "true" );
		
		// settings
		Base.readSettingsFromIni( "PROJECT.SETTINGS" );
		
		// handle automatic update
		if ( Base.handleUpdateOnStart() )
			setstring( "UPDATE_ON_START", "AUTOUPDATE", "true" );
	}
	
	// ================================================================================================
	// general menu event handling
	// ================================================================================================
	if ( event == 'IDC_START' )
	{
		new_dlg = 'IDD_START';

		// handle autoupdate stuff
		var strPathAutoupdate = 'AUTOUPDATE';
		var bUpdateOnStart = ( getstring( 'UPDATE_ON_START', strPathAutoupdate ) === 'true' );
		var bShowDisclaimer = ( getstring( 'SHOWDISCLAIMERONSTART', 'PROJECT.SETTINGS' ) === 'true' );

		if ( bUpdateOnStart && !bShowDisclaimer )
		{
			setstring( 'UPDATE_ON_START', strPathAutoupdate, 'false' );
			new_dlg = 'IDD_UPDATE';
		}
	}
	else if ( event == "IDC_ABOUT" )
		new_dlg = "IDD_ABOUT";
	else if ( event == "IDC_UPDATE" )
		new_dlg = "IDD_UPDATE";
	else if ( event == "IDC_ADRESSE" )
		new_dlg = "IDD_ADRESSES";
	else if ( event == "IDC_VORZUGSTYPEN" )
		new_dlg = "IDD_VORZUGSTYPEN";
	else if ( event == "IDC_MASSSYSTEM" )
		new_dlg = "IDD_MEASUREMENT_SYSTEM";
	else if ( event == "IDC_DEFAULT_MASSEINHEITEN" )
		new_dlg = "IDD_DEFAULT_MASSEINHEITEN";
	else if ( event == "IDC_SONSTIGE_EINSTELLUNGEN" )
		new_dlg = "IDD_OTHER_SETTINGS";
	else if ( event == "IDC_SPRACHEN" )
		new_dlg = "IDD_LANGUAGES";
	else if ( event == "IDC_PROJEKTORGANISATION" )
		new_dlg = "IDD_PROJECTLIST";
	else if ( event == "IDC_MECH_BEWEGUNG" )
		new_dlg = "IDD_APPLICATION_SELECTION";
	else if ( event == "IDC_DATEN_MECHANIK" )
		new_dlg = "IDD_MECHANICS";
	else if ( event == "IDC_DATEN_BEWEGUNG" )
		new_dlg = Control._getMotionProfileDlg( current_dlg );
	else if ( event == "IDC_ANTRIEBSAUSWAHL" )
		new_dlg = Control._getMotorSearchDlg( current_dlg );
	else if ( event == "IDC_ANTRIEBSAUSWAHL_DIREKT" )
		new_dlg = "IDD_DIRECT_SELECTION";
	else if ( event == "IDC_DIREKTE_ANTRIEBSAUSWAHL" )
		new_dlg = "IDD_DIRECT_SELECTION";
	else if ( event == "IDC_ANTRIEBSBERECHNUNG" )
		new_dlg = "IDD_APPLICATION_SELECTION";

	// ================================================================================================
	// event handling for start dialog
	// ================================================================================================

	if ( current_dlg == "IDD_START" )
	{
		if ( ( event == "IDC_DIRECT_IMAGE" ) || ( event == "IDC_DIRECT_LABEL" ) )
			new_dlg = "IDD_DIRECT_SELECTION";
		else if ( ( event == "IDC_FULL_AXIS_IMAGE" ) || ( event == "IDC_FULL_AXIS_LABEL" ) )
			new_dlg = "IDD_APPLICATION_SELECTION";
	}

	// ================================================================================================
	// event handling for about dialog
	// ================================================================================================

	if ( current_dlg == "IDD_ABOUT" )
		new_dlg = "IDD_START";

	// ================================================================================================
	// event handling for project list dialog
	// ================================================================================================

	if ( current_dlg == "IDD_PROJECTLIST" )
	{
		new_dlg = "IDD_PROJECTLIST";

		// drive group
		if ( event == "IDC_DIREKTE_ANTRIEBSAUSWAHL_BUTTON" )
			new_dlg = "IDD_DIRECT_SELECTION";
		else if ( event == "IDC_ANTRIEBSBERECHNUNG_BUTTON" )
			new_dlg ="IDD_APPLICATION_SELECTION";
		else if ( event == "IDC_BEARBEITEN_BUTTON" )
			new_dlg = Control._getSelectionStartDlg( current_dlg, event );
	}

	// ================================================================================================
	// event handling for preferred types dialog
	// ================================================================================================
	if ( current_dlg == "IDD_VORZUGSTYPEN" )
	{
		new_dlg = "IDD_VORZUGSTYPEN";
		if ( ( event == "IDC_ABBRECHEN_BUTTON" ) || ( event == "IDC_UEBERNEHMEN_BUTTON" ) )
			new_dlg = "IDD_START";
	}
	
	// ================================================================================================
	// event handling for adresses dialog
	// ================================================================================================

	if ( current_dlg == "IDD_ADRESSES" )
		new_dlg = "IDD_START";

	// ================================================================================================
	// event handling for measurement dialog
	// ================================================================================================

	if ( current_dlg == "IDD_MEASUREMENT_SYSTEM" )
		new_dlg = "IDD_START";

	// ================================================================================================
	// event handling for default measures dialog
	// ================================================================================================

	if ( current_dlg == "IDD_DEFAULT_MASSEINHEITEN" )
	{
		new_dlg = "IDD_START";
		if ( ( event == "IDC_DEFAULT_BRITISCH_BUTTON" ) || ( event == "IDC_DEFAULT_METRISCH_BUTTON" ) )
		    new_dlg = "IDD_DEFAULT_MASSEINHEITEN";
    }
	// ================================================================================================
	// event handling for other settings dialog
	// ================================================================================================

	if ( current_dlg == "IDD_OTHER_SETTINGS" )
	{
		new_dlg = "IDD_OTHER_SETTINGS";
		if ( ( event == "IDC_ABBRECHEN_BUTTON" ) || ( event == "IDC_UEBERNEHMEN_BUTTON" ) )
			new_dlg = "IDD_START";
	}

	// ================================================================================================
	// event handling for languages dialog
	// ================================================================================================

	if ( current_dlg == "IDD_LANGUAGES" )
	{
		new_dlg = "IDD_LANGUAGES";
		if ( ( event == "IDC_ABBRECHEN_BUTTON" ) || ( event == "IDC_UEBERNEHMEN_BUTTON" ) )
			new_dlg = "IDD_START";
	}

	// ================================================================================================
	// event handling for application selection dialog
	// ================================================================================================

	if ( current_dlg == "IDD_APPLICATION_SELECTION" )
	{
		if ( event == "IDC_ZURUECK_BUTTON" )
			new_dlg = "IDD_PROJECTLIST";
		else if ( event == "IDC_WEITER_BUTTON" )
			new_dlg = Control._getMechanicsDlg( current_dlg );
		else if ( event == "IDC_ABBRECHEN_BUTTON" )
			new_dlg = "IDD_PROJECTLIST";
	}

	// ================================================================================================
	// event handling for mechanics dialog
	// ================================================================================================

	if ( ( current_dlg == "IDD_MECHANICS" ) || ( current_dlg == "IDD_MECHANICS_ROTARY_KNIFE" ) ||
	     ( current_dlg == "IDD_MECHANICS_ROLLER_FEED" ) )
	{
		if ( event == "IDC_ZURUECK_BUTTON" )
			new_dlg = "IDD_APPLICATION_SELECTION";
		else if ( event == "IDC_WEITER_BUTTON" )
			new_dlg = Control._getMotionProfileDlg( current_dlg );
		else if ( event == "IDC_ABBRECHEN_BUTTON" )
			new_dlg = "IDD_PROJECTLIST";
		else
		{
			var calc_type = getstring( "CALCULATOR_TYPE", "DLGDATA.DLGVARS.IDD_MECHANICS" );
			if ( calc_type != "" )
			{
				if ( calc_type === 'CALCULATION_BELT_DRIVE' )
					new_dlg = 'IDD_CALCULATION_GEAR_RATIO';
				else new_dlg = "IDD_" + calc_type;
			}
			else
			{
				var values_type = getstring( "TYPICAL_VALUES_TYPE", "DLGDATA.DLGVARS.IDD_MECHANICS" );
				if ( values_type != "" )
					new_dlg = "IDD_" + values_type;
			}
		}
	}

	// ================================================================================================
	// event handling for calculators
	// ================================================================================================

	if ( ( current_dlg == "IDD_CALCULATION_MASS" ) || ( current_dlg == "IDD_CALCULATION_INERTIA_SPINDLE" ) || 
             ( current_dlg == "IDD_CALCULATION_INERTIA_NUT" ) || ( current_dlg == "IDD_CALCULATION_INERTIA_RACK_AND_PINION" ) || 
             ( current_dlg == "IDD_CALCULATION_INERTIA_BELT_AND_PULLEY" ) || ( current_dlg == "IDD_CALCULATION_INERTIA_ROLL_FEED" ) || 
             ( current_dlg == "IDD_CALCULATION_INERTIA_BLACK_BOX" ) || ( current_dlg == "IDD_CALCULATION_INERTIA_COUPLING" ) || 
             ( current_dlg == "IDD_CALCULATION_GEAR_RATIO" ) || ( current_dlg == "IDD_CALCULATION_INERTIA_TABLE" ) || 
             ( current_dlg == "IDD_CALCULATION_INERTIA_ROTARY_KNIFE" ) || ( current_dlg == "IDD_CALCULATION_INERTIA_ROLLER_COUPLING" ) || 
             ( current_dlg == "IDD_CALCULATION_INERTIA_FEED_ROLLERS" ) || ( current_dlg == "IDD_CALCULATION_INERTIA_STRAIGHTENING_ROLLERS" ) || 
             ( current_dlg == "IDD_CALCULATION_INERTIA_WORKPIECE" ) )
	{
		if ( ( event == "IDC_ABBRECHEN_BUTTON" ) || ( event == "IDC_UEBERNEHMEN_BUTTON" ) || ( event == "IDC_APPLY_PFEIL" ) )
			new_dlg = Control._getMechanicsDlg( current_dlg );
		else
		{
			var values_type = getstring( "TYPICAL_VALUES_TYPE", "DLGDATA.DLGVARS.IDD_MECHANICS" );
			if ( values_type != "" )
				new_dlg = "IDD_" + values_type;
		}
	}

	// ================================================================================================
	// event handling for typical values
	// ================================================================================================
	
	if ( ( current_dlg == "IDD_TYPISCHE_DICHTEN" ) || ( current_dlg == "IDD_TYPISCHE_REIBWERTE" ) )
	{
		if ( ( event == "IDC_ABBRECHEN_BUTTON" ) || ( event == "IDC_UEBERNEHMEN_BUTTON" ) )
		{
			var values_started = getstring( "TYPICAL_VALUES_STARTED", "DLGDATA.DLGVARS.IDD_MECHANICS" );
			if ( values_started != "" )
				new_dlg = values_started;
			else new_dlg = Control._getMechanicsDlg( current_dlg );
		}
	}

	// ================================================================================================
	// event handling for motion profile dialogs and for relative power-on-time dialog
	// ================================================================================================

	if ( ( current_dlg == "IDD_MOTION_PROFILE" ) || ( current_dlg == "IDD_MOTION_PROFILE_ROTATIVE" ) ||
	     ( current_dlg == "IDD_MOTION_PROFILE_FLYING_CUTOFF" ) || ( current_dlg == "IDD_MOTION_PROFILE_WINDER" ) ||
	     ( current_dlg == "IDD_MOTION_PROFILE_ROTARY_KNIFE" ) || ( current_dlg == "IDD_MOTION_PROFILE_ROLL_FEED" ) )
	{
		if ( event == "IDC_ZURUECK_BUTTON" )
			new_dlg = Control._getMechanicsDlg( current_dlg );
		else if ( event == "IDC_WEITER_BUTTON" )
			new_dlg = Control._getMotorSearchDlg( current_dlg );
		else if ( event == "IDC_LUPE_IMAGE" )
		{
			if ( current_dlg == "IDD_MOTION_PROFILE" )
				new_dlg = "IDD_MOTION_PROFILE_IMAGE";
			else if ( current_dlg == "IDD_MOTION_PROFILE_ROTATIVE" )
				new_dlg = "IDD_MOTION_PROFILE_ROTATIVE_IMAGE";
			else if ( current_dlg == "IDD_MOTION_PROFILE_FLYING_CUTOFF" )
			    new_dlg = "IDD_MOTION_PROFILE_FLYING_CUTOFF_IMAGE";
			else if ( current_dlg == "IDD_MOTION_PROFILE_ROTARY_KNIFE" )
			    new_dlg = "IDD_MOTION_PROFILE_ROTARY_KNIFE_IMAGE";
			else if ( current_dlg == "IDD_MOTION_PROFILE_ROLL_FEED" )
			    new_dlg = "IDD_MOTION_PROFILE_ROLL_FEED_IMAGE";
		}
		else if ( event == "IDC_ABBRECHEN_BUTTON" )
			new_dlg = "IDD_PROJECTLIST";
			
		if ( current_dlg == "IDD_MOTION_PROFILE_ROTARY_KNIFE" )
		{
		    if ( ( event == "IDC_BEWEGUNGSPHASE_MIN_LUPE_IMAGE" ) || ( event == "IDC_BEWEGUNGSPHASE_MAX_LUPE_IMAGE" ) ||
		         ( event == "IDC_CAM_MIN_LUPE_IMAGE" ) || ( event == "IDC_CAM_MAX_LUPE_IMAGE" ) )
			    new_dlg = "IDD_MOTION_PROFILE_ROTARY_KNIFE_IMAGE";
		}
	}

	// ================================================================================================
	// event handling for motion profile image dialog
	// ================================================================================================

	if ( ( current_dlg == "IDD_MOTION_PROFILE_IMAGE" ) || ( current_dlg == "IDD_MOTION_PROFILE_ROTATIVE_IMAGE" ) ||
	     ( current_dlg == "IDD_MOTION_PROFILE_FLYING_CUTOFF_IMAGE" ) || ( current_dlg == "IDD_MOTION_PROFILE_ROTARY_KNIFE_IMAGE" ) ||
	     ( current_dlg == "IDD_MOTION_PROFILE_ROLL_FEED_IMAGE" ) )
	{
		if ( ( event == "IDC_ZURUECK_BUTTON" ) || ( event == "IDC_SCHLIESSEN_BUTTON" ) )
			new_dlg = Control._getMotionProfileDlg( current_dlg );
		else if ( event == "IDC_ABBRECHEN_BUTTON" )
			new_dlg = "IDD_PROJECTLIST";
	}

	// ================================================================================================
	// event handling for relative power-on-time dialogs
	// ================================================================================================

	if ( ( current_dlg == "IDD_RELATIVE_ONTIME_ROTATIVE" ) || ( current_dlg == "IDD_RELATIVE_ONTIME_LINEAR" ) ||
	     ( current_dlg == "IDD_RELATIVE_ONTIME_ROTARY_DRIVE" ) )
	{
		if ( event == "IDC_ZURUECK_BUTTON" )
			new_dlg = Control._getMechanicsDlg( current_dlg );
		else if ( event == "IDC_WEITER_BUTTON" )
			new_dlg = Control._getMotorSearchDlg( current_dlg );
		else if ( event == "IDC_ABBRECHEN_BUTTON" )
			new_dlg = "IDD_PROJECTLIST";
	}

	// ================================================================================================
	// event handling for direct selection dlg
	// ================================================================================================

	if ( current_dlg == "IDD_DIRECT_SELECTION" )
	{
		if ( event == "IDC_ZURUECK_BUTTON" )
			new_dlg = "IDD_PROJECTLIST";
		else if ( event == "IDC_WEITER_BUTTON" )
			new_dlg = "IDD_PROJECTLIST";
		else if ( event == "IDC_ABBRECHEN_BUTTON" )
			new_dlg = "IDD_PROJECTLIST";
		else if ( event == "IDC_DETAILS_BUTTON" )
		{
			// branch on behalf of the current selected tab in the direct selection dialog
			var current_tab = getstring( "SEARCH_LIST","DLGDATA.DLGVARS.IDD_DIRECT_SELECTION" );	// actual selected tab
			if ( current_tab == "LINEAR" )
				new_dlg = "IDD_DETAILS_LINEAR";
			else if ( current_tab == "ROTATIVE" )
				new_dlg = "IDD_DETAILS_ROTATIVE"; 
			else if ( current_tab == "S1" )
				new_dlg = "IDD_DETAILS_S1"; 
			else if ( current_tab == "MAIN_SPINDLE" )
				new_dlg = "IDD_DETAILS_MAIN_SPINDLE"; 
		}
	}

	// ================================================================================================
	// event handling for full motor search dialogs
	// ================================================================================================

	if ( ( current_dlg == "IDD_MOTORSEARCH_LINEAR" ) || ( current_dlg == "IDD_MOTORSEARCH_S1" ) || 
	     ( current_dlg == "IDD_MOTORSEARCH_MAIN_SPINDLE" ) || ( current_dlg == "IDD_MOTORSEARCH_ROTATIVE" ) ||
	     ( current_dlg == "IDD_MOTORSEARCH_ROTARY_KNIFE" ) )
	{
		new_dlg = current_dlg;
		if ( event == "IDC_ZURUECK_BUTTON" )
			new_dlg = Control._getMotionProfileDlg( current_dlg );
		else if ( event == "IDC_WEITER_BUTTON" )
			new_dlg = "IDD_PROJECTLIST";
		else if ( event == "IDC_ABBRECHEN_BUTTON" )
			new_dlg = "IDD_PROJECTLIST";
		else if ( event == "IDC_DETAILS_BUTTON" )
		{
			if ( current_dlg == "IDD_MOTORSEARCH_LINEAR" )
				new_dlg = "IDD_DETAILS_LINEAR"; 
			else if ( ( current_dlg == "IDD_MOTORSEARCH_ROTATIVE" ) || ( current_dlg == "IDD_MOTORSEARCH_ROTARY_KNIFE" ) )
				new_dlg = "IDD_DETAILS_ROTATIVE"; 
			else if ( current_dlg == "IDD_MOTORSEARCH_S1" )
				new_dlg = "IDD_DETAILS_S1"; 
			else if ( current_dlg == "IDD_MOTORSEARCH_MAIN_SPINDLE" )
				new_dlg = "IDD_DETAILS_MAIN_SPINDLE"; 
		}
	}

	// ================================================================================================
	// event handling for details dialogs
	// ================================================================================================

	if ( ( current_dlg == "IDD_DETAILS_LINEAR" ) || ( current_dlg == "IDD_DETAILS_ROTATIVE" ) ||
		 ( current_dlg == "IDD_DETAILS_S1" ) || ( current_dlg == "IDD_DETAILS_MAIN_SPINDLE" ) )
	{
		if ( event == "IDC_SCHLIESSEN_BUTTON" )
		{
			var SelectionType = getstring( "SELECTION_TYPE","DLGDATA.DLGVARS" );	// actual type of selection
			if( SelectionType == "DIRECT" )			
				new_dlg = "IDD_DIRECT_SELECTION";
			else new_dlg = Control._getMotorSearchDlg( current_dlg );
		}
		else if ( event == "IDC_ABBRECHEN_BUTTON" )
			new_dlg = "IDD_PROJECTLIST";
	}

	//---------------------------------------------------
	// event handling for update dialog
	//---------------------------------------------------
	if ( current_dlg == "IDD_UPDATE" )
	{
		if ( event == "IDC_LOCAL_UPDATE" )
		{
			var str7zFile = filedialog( 1, "7z", "", "Update-Files|*.7z;*.7Z||", "" );
			if ( str7zFile != "" )
			{
				var catalogName = getstring( "CATALOG.NAME", "ROOT" );
				str7zFile = replace( str7zFile, "\\", "/" );

				var param = "";
				param += " --url=file:///"+str7zFile;				// Link zum Installer 
				//param += " --no-cache";							// Keinen Datei auch dem Cache
				//param += " --exec";								// Den Installer automatisch starten
				param += " --close-pid="+getcurrentprocessid();	    // Diesen Process noch vor dem Start des Installers 
				//param += " --close-name="+"IndraSize.exe";		// beenden (WM_CLOSE).
				param += " --kill-timeout=60000"					// Nach max. 60s den Prozess tten (TerminateProcess)
				param += " --window-title="+'"'+catalogName+'"';	// EasyKat Name (spez.)

				param += " --extract-to=./";
				param += " --shell-exec=IndraSize.exe"
				
				shellexecuteex( getstddirectory( "PROGRAM" ) + "netupd.exe", param, "", 1 );		
			}
		}
	}
	
	// ================================================================================================
	// reset current event and set new dialog id
	// ================================================================================================

	//print "new_dlg=" + new_dlg + ", event=" + event
	setstring( "EKSUBMITEVENT", "", event );
	setstring( "AKTUELLE_MASKE", "", new_dlg );
}
